'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var DARK_COLOR = 'rgb(63, 63, 63)';
var DARK_COLOR_BACKGROUND = 'rgba(63, 63, 63, 0.7)';
var LIGHT_COLOR = 'rgb(243, 243, 243)';
var LIGHT_COLOR_BACKGROUND = 'rgba(243, 243, 243, 0.7)';
var TRACK_BUTTON_SIZE = 12;
var BOX_SHADOW_SIZE = '0 0 3px';

var ALL_STYLES = {
  actionsContainer: {
    alignItems: 'stretch',
    display: 'flex',
    flexDirection: 'row',
    flexWrap: 'nowrap'
  },
  button: {
    alignItems: 'center',
    cursor: 'pointer',
    display: 'flex',
    flexBasis: 'auto',
    flexDirection: 'row',
    flexGrow: 0,
    flexShrink: 0,
    flexWrap: 'nowrap',
    fontSize: 16
  },
  container: {
    position: 'relative'
  },
  control: {
    height: 40,
    lineHeight: '40px',
    padding: '0 10px'
  },
  controlsContainer: {
    bottom: 0,
    left: 0,
    opacity: 1,
    position: 'absolute',
    right: 0,
    transition: 'opacity 150ms ease-in-out, visibility 150ms ease-in-out',
    visibility: 'visible'
  },
  durationSlider: {
    cursor: 'pointer',
    position: 'relative'
  },
  durationTrack: {
    height: 2,
    marginTop: -1,
    position: 'relative',
    top: '50%',
    width: 0
  },
  fullscreenButton: {
    flexBasis: 'auto',
    flexGrow: 0,
    flexShrink: 0
  },
  informationContainer: {
    fontFamily: '"Helvetica Neue", Helvetica, Arial, sans-serif',
    fontSize: 12,
    flexBasis: 0,
    flexGrow: 1,
    flexShrink: 0,
    minWidth: 1
  },
  playPauseButton: {
    flexBasis: 'auto',
    flexGrow: 0,
    flexShrink: 0
  },
  speedIdentifier: {
    fontFamily: '"Helvetica Neue", Helvetica, Arial, sans-serif',
    fontSize: 11
  },
  trackButton: {
    borderRadius: '50%',
    display: 'block',
    height: TRACK_BUTTON_SIZE,
    position: 'absolute',
    width: TRACK_BUTTON_SIZE
  },
  video: {
    objectFit: 'fill'
  },
  volumeButton: {
    boxSizing: 'border-box',
    textAlign: 'center',
    width: 40
  },
  volumeChange: {
    backgroundColor: 'inherit',
    bottom: '100%',
    boxSizing: 'border-box',
    color: 'inherit',
    cursor: 'pointer',
    display: 'none',
    height: 100,
    left: 0,
    padding: '10px 0',
    position: 'absolute',
    width: '100%'
  },
  volumeChangeActive: {
    display: 'block'
  },
  volumnChangeContainer: {
    backgroundColor: 'inherit',
    color: 'inherit',
    position: 'relative',
    zIndex: 1000
  },
  volumeChangeTrack: {
    height: '100%',
    left: '50%',
    marginLeft: -1,
    position: 'relative',
    width: 2
  }
};

var darkStyles = _extends({}, ALL_STYLES, {
  control: _extends({}, ALL_STYLES.control, {
    backgroundColor: DARK_COLOR_BACKGROUND,
    color: LIGHT_COLOR
  }),
  durationSlider: _extends({}, ALL_STYLES.durationSlider),
  durationTrack: _extends({}, ALL_STYLES.durationTrack, {
    backgroundColor: LIGHT_COLOR
  }),
  durationTrackButton: _extends({}, ALL_STYLES.trackButton, {
    backgroundColor: LIGHT_COLOR,
    boxShadow: BOX_SHADOW_SIZE + ' ' + DARK_COLOR,
    left: 0,
    marginTop: -1 * (TRACK_BUTTON_SIZE / 2 + 1),
    top: '50%'
  }),
  volumeChange: _extends({}, ALL_STYLES.volumeChange, {
    backgroundColor: DARK_COLOR_BACKGROUND
  }),
  volumeChangeTrack: _extends({}, ALL_STYLES.volumeChangeTrack, {
    backgroundColor: LIGHT_COLOR
  }),
  volumeTrackButton: _extends({}, ALL_STYLES.trackButton, {
    backgroundColor: LIGHT_COLOR,
    boxShadow: BOX_SHADOW_SIZE + ' ' + DARK_COLOR,
    left: '50%',
    marginLeft: -1 * (TRACK_BUTTON_SIZE / 2),
    top: 6
  })
});

exports.darkStyles = darkStyles = _extends({}, darkStyles, {
  fastForwardButton: _extends({}, ALL_STYLES.button, darkStyles.control, ALL_STYLES.fastForwardButton),
  fullscreenButton: _extends({}, ALL_STYLES.button, darkStyles.control, ALL_STYLES.fullscreenButton),
  informationContainer: _extends({}, ALL_STYLES.informationContainer, darkStyles.control),
  playPauseButton: _extends({}, ALL_STYLES.button, darkStyles.control, ALL_STYLES.playPauseButton),
  volumeButton: _extends({}, ALL_STYLES.button, darkStyles.control, ALL_STYLES.volumeButton)
});

var lightStyles = _extends({}, ALL_STYLES, {
  control: _extends({}, ALL_STYLES.control, {
    backgroundColor: LIGHT_COLOR_BACKGROUND,
    color: DARK_COLOR
  }),
  durationSlider: _extends({}, ALL_STYLES.durationSlider),
  durationTrack: _extends({}, ALL_STYLES.durationTrack, {
    backgroundColor: DARK_COLOR
  }),
  durationTrackButton: _extends({}, ALL_STYLES.trackButton, {
    backgroundColor: DARK_COLOR,
    boxShadow: BOX_SHADOW_SIZE + ' ' + LIGHT_COLOR,
    left: 0,
    marginTop: -1 * (TRACK_BUTTON_SIZE / 2 + 1),
    top: '50%'
  }),
  volumeChange: _extends({}, ALL_STYLES.volumeChange, {
    backgroundColor: LIGHT_COLOR_BACKGROUND
  }),
  volumeChangeTrack: _extends({}, ALL_STYLES.volumeChangeTrack, {
    backgroundColor: DARK_COLOR
  }),
  volumeTrackButton: _extends({}, ALL_STYLES.trackButton, {
    backgroundColor: LIGHT_COLOR,
    boxShadow: BOX_SHADOW_SIZE + ' ' + DARK_COLOR,
    left: '50%',
    marginLeft: -1 * (TRACK_BUTTON_SIZE / 2 + 1),
    top: 0
  })
});

exports.lightStyles = lightStyles = _extends({}, lightStyles, {
  fastForwardButton: _extends({}, ALL_STYLES.button, lightStyles.control, ALL_STYLES.fastForwardButton),
  fullscreenButton: _extends({}, ALL_STYLES.button, lightStyles.control, ALL_STYLES.fullscreenButton),
  informationContainer: _extends({}, ALL_STYLES.informationContainer, lightStyles.control),
  playPauseButton: _extends({}, ALL_STYLES.button, lightStyles.control, ALL_STYLES.playPauseButton),
  volumeButton: _extends({}, ALL_STYLES.button, lightStyles.control, ALL_STYLES.volumeButton)
});

exports.allStyles = ALL_STYLES;
exports.darkStyles = darkStyles;
exports.lightStyles = lightStyles;
exports.default = {
  allStyles: ALL_STYLES,
  darkStyles: darkStyles,
  lightStyles: lightStyles
};